@@ -1,8 +1,8 @@
 /*
    +----------------------------------------------------------------------+
-   | PHP Version 5                                                        |
+   | PHP Version 7                                                        |
    +----------------------------------------------------------------------+
-   | Copyright (c) 1997-2008 The PHP Group                                |
+   | Copyright (c) 1997-2016 The PHP Group                                |
    +----------------------------------------------------------------------+
    | This source file is subject to version 3.01 of the PHP license,      |
    | that is bundled with this package in the file LICENSE, and is        |
@@ -16,7 +16,7 @@
    +----------------------------------------------------------------------+
 */
 
-/* $Id: php_dbase.h,v 1.18 2007/12/31 07:12:08 sebastian Exp $ */
+/* $Id: php_dbase.h 348190 2019-10-20 13:06:01Z cmb $ */
 
 #ifndef PHP_DBASE_H
 #define PHP_DBASE_H
@@ -42,15 +42,6 @@ PHP_FUNCTION(dbase_get_header_info);
 
 #define phpext_dbase_ptr dbase_module_ptr
 
-#define PHP_DBASE_VERSION "5.1.1"
-
-/*
- * zend_list_insert() has changed its prototype as of PHP 5.4
- */
-#if PHP_VERSION_ID >= 50400
-#define ZEND_LIST_CC TSRMLS_CC
-#else
-#define ZEND_LIST_CC
-#endif
+#define PHP_DBASE_VERSION "7.0.1"
 
 #endif /* PHP_DBASE_H */
